@@ -10,7 +10,16 @@ extends 'App::Alice::Window';
 has '+is_channel' => (lazy => 0, default => 0);
 has '+id' => (default => 'info');
 has '+title' => (required => 0, default => 'info');
-has '+irc' => (required => 0);
+has '+irc' => (required => 0, lazy => 1, default => sub {
+  my $self = shift;
+  if ($self->app->connected_ircs == 1) {
+    return ($self->app->connected_ircs)[0];
+  }
+  $self->app->broadcast(
+    $self->format_announcement("Connected to multiple servers and no server specified! /command -server args")
+  );
+  return undef;
+});
 has '+session' => ( isa => 'Undef', default => undef);
 has 'topic' => (is => 'ro', isa => 'HashRef', default => sub {{string => ''}});
 has '+buffersize' => (default => 300);
